TempKey

Struct TempKey 

pub struct TempKey<T: AsMut<[u8]>>(/* private fields */);
Temporary Key

use seckey::{ TempKey, CmpKey };

let mut key = [8u8; 8];
let key = TempKey::new(&mut key);
assert_eq!(CmpKey(&key[..]), &[8u8; 8][..]);

Note

  • It will zero the value when Drop.
  • It will refuse to accept if T is reference or pointer, to avoid causing null pointer.
  • It is a reference, to avoid it from being affected by stack copy (return value).

Implementations

Source

impl<T: AsMut<[u8]>> TempKey<T>

pub fn new(t: T) -> TempKey<T>